@@ -5,9 +5,8 @@ import logging
 import re
 
 from prometheus_aioexporter import MetricsRegistry
-import yaml
-
 import pytest
+import yaml
 
 from .. import loop
 from ..config import load_config
@@ -64,7 +63,8 @@ async def make_query_loop(tmpdir, config_data, registry):
 
     yield make_loop
     await asyncio.gather(
-        *(query_loop.stop() for query_loop in query_loops), return_exceptions=True,
+        *(query_loop.stop() for query_loop in query_loops),
+        return_exceptions=True,
     )
 
 
@@ -217,9 +217,9 @@ class TestQueryLoop:
             'running query "q" on database "db"',
             'updating metric "m" set 100.0 {database="db"}',
             re_match(
-                r'updating metric "query_latency" observe .* \{database="db",query="q\"}'
+                r'updating metric "query_latency" observe .* \{database="db",query="q"\}'
             ),
-            'updating metric "queries" inc 1 {database="db",status="success"}',
+            'updating metric "queries" inc 1 {database="db",query="q",status="success"}',
         ]
 
     async def test_run_query_log_labels(
@@ -237,9 +237,9 @@ class TestQueryLoop:
             'running query "q" on database "db"',
             'updating metric "m" set 100.0 {database="db",l="foo"}',
             re_match(
-                r'updating metric "query_latency" observe .* \{database="db",query="q\"}'
+                r'updating metric "query_latency" observe .* \{database="db",query="q"\}'
             ),
-            'updating metric "queries" inc 1 {database="db",status="success"}',
+            'updating metric "queries" inc 1 {database="db",query="q",status="success"}',
         ]
 
     async def test_run_query_increase_db_error_count(
@@ -264,6 +264,25 @@ class TestQueryLoop:
         queries_metric = registry.get_metric("queries")
         assert metric_values(queries_metric, by_labels=("status",)) == {("error",): 1.0}
 
+    async def test_run_query_increase_timeout_count(
+        self, query_tracker, config_data, make_query_loop, registry
+    ):
+        """Count of errored queries is incremented on timeout."""
+        config_data["queries"]["q"]["timeout"] = 0.1
+        query_loop = make_query_loop()
+        await query_loop.start()
+
+        async def execute(sql, parameters):
+            await asyncio.sleep(1)  # longer than timeout
+
+        query_loop._config.databases["db"]._conn.execute = execute
+
+        await query_tracker.wait_failures()
+        queries_metric = registry.get_metric("queries")
+        assert metric_values(queries_metric, by_labels=("status",)) == {
+            ("timeout",): 1.0
+        }
+
     async def test_run_query_at_interval(self, advance_time, query_tracker, query_loop):
         """Queries are run at the specified time interval."""
         await query_loop.start()
